summaryrefslogtreecommitdiffstats
path: root/pykdeconfig.py
diff options
context:
space:
mode:
Diffstat (limited to 'pykdeconfig.py')
-rw-r--r--pykdeconfig.py22
1 files changed, 11 insertions, 11 deletions
diff --git a/pykdeconfig.py b/pykdeconfig.py
index 1ec43f8..fa4b3b6 100644
--- a/pykdeconfig.py
+++ b/pykdeconfig.py
@@ -38,7 +38,7 @@ _pkg_config = {
'libdir': 'lib',
'pykde_kde_sip_flags': '-t ALL -x Qt_STYLE_WINDOWSXP -x Qt_STYLE_INTERLACE -x Qt_STYLE_WINDOWSXP -x Qt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t Qt_3_3_6 -t KDE_3_5_3',
'pykde_mod_dir': '/usr/lib/python2.5/site-packages',
- 'pykde_modules': 'dcop kdecore kdefx kdeui kio kresources kabc kutils kfile kparts khtml kspell kdeprint kmdi',
+ 'pykde_modules': 'dcop tdecore tdefx tdeui kio kresources kabc kutils kfile kparts khtml kspell tdeprint kmdi',
'pykde_sip_dir': '/usr/share/sip',
'pykde_version': 0x031000,
'pykde_version_str': '3.16.0'
@@ -82,7 +82,7 @@ class DCOPModuleMakefile(pyqtconfig.QtModuleMakefile):
pyqtconfig.QtModuleMakefile.finalise(self)
class KdecoreModuleMakefile(DCOPModuleMakefile):
"""The Makefile class for modules that %Import kdecore.
"""
def finalise(self):
"""Finalise the macros.
@@ -91,12 +91,12 @@ class KdecoreModuleMakefile(DCOPModuleMakefile):
# Note that we don't use self.extra_lib_dirs because we don't want
# it to be added to the rpath.
self.LIBDIR.append(self.config.pyqt_mod_dir)
- self.extra_libs.append(self.module_as_lib("kdecore"))
+ self.extra_libs.append(self.module_as_lib("tdecore"))
DCOPModuleMakefile.finalise(self)
class KdesuModuleMakefile(KdecoreModuleMakefile):
"""The Makefile class for modules that %Import kdesu.
"""
def finalise(self):
"""Finalise the macros.
@@ -105,12 +105,12 @@ class KdesuModuleMakefile(KdecoreModuleMakefile):
# Note that we don't use self.extra_lib_dirs because we don't want
# it to be added to the rpath.
self.LIBDIR.append(self.config.pyqt_mod_dir)
- self.extra_libs.append(self.module_as_lib("kdesu"))
+ self.extra_libs.append(self.module_as_lib("tdesu"))
KdecoreModuleMakefile.finalise(self)
class KdefxModuleMakefile(KdecoreModuleMakefile):
"""The Makefile class for modules that %Import kdefx.
"""
def finalise(self):
"""Finalise the macros.
@@ -119,12 +119,12 @@ class KdefxModuleMakefile(KdecoreModuleMakefile):
# Note that we don't use self.extra_lib_dirs because we don't want
# it to be added to the rpath.
self.LIBDIR.append(self.config.pyqt_mod_dir)
- self.extra_libs.append(self.module_as_lib("kdefx"))
+ self.extra_libs.append(self.module_as_lib("tdefx"))
KdecoreModuleMakefile.finalise(self)
class KdeuiModuleMakefile(KdefxModuleMakefile):
"""The Makefile class for modules that %Import kdeui.
"""
def finalise(self):
"""Finalise the macros.
@@ -133,7 +133,7 @@ class KdeuiModuleMakefile(KdefxModuleMakefile):
# Note that we don't use self.extra_lib_dirs because we don't want
# it to be added to the rpath.
self.LIBDIR.append(self.config.pyqt_mod_dir)
- self.extra_libs.append(self.module_as_lib("kdeui"))
+ self.extra_libs.append(self.module_as_lib("tdeui"))
if self.config.sip_version < 0x040000:
self.extra_libs.append(self.module_as_lib("qtxml"))
@@ -211,7 +211,7 @@ class KjsModuleMakefile(KhtmlModuleMakefile):
KjsModuleMakefile.finalise(self)
class KdeprintModuleMakefile(KdeuiModuleMakefile):
"""The Makefile class for modules that %Import kdeprint.
"""
def finalise(self):
"""Finalise the macros.
@@ -220,6 +220,6 @@ class KdeprintModuleMakefile(KdeuiModuleMakefile):
# Note that we don't use self.extra_lib_dirs because we don't want
# it to be added to the rpath.
self.LIBDIR.append(self.config.pyqt_mod_dir)
- self.extra_libs.append(self.module_as_lib("kdeprint"))
+ self.extra_libs.append(self.module_as_lib("tdeprint"))
KdeuiModuleMakefile.finalise(self)
@@ -82,7 +82,7 @@ class DCOPModuleMakefile(pyqtconfig.QtModuleMakefile):
pyqtconfig.QtModuleMakefile.finalise(self)
class KdecoreModuleMakefile(DCOPModuleMakefile):
- """The Makefile class for modules that %Import kdecore.
+ """The Makefile class for modules that %Import tdecore.
"""
def finalise(self):
@@ -91,12 +91,12 @@ class KdecoreModuleMakefile(DCOPModuleMakefile):
DCOPModuleMakefile.finalise(self)
class KdesuModuleMakefile(KdecoreModuleMakefile):
- """The Makefile class for modules that %Import kdesu.
+ """The Makefile class for modules that %Import tdesu.
"""
def finalise(self):
@@ -105,12 +105,12 @@ class KdesuModuleMakefile(KdecoreModuleMakefile):
KdecoreModuleMakefile.finalise(self)
class KdefxModuleMakefile(KdecoreModuleMakefile):
- """The Makefile class for modules that %Import kdefx.
+ """The Makefile class for modules that %Import tdefx.
"""
def finalise(self):
@@ -119,12 +119,12 @@ class KdefxModuleMakefile(KdecoreModuleMakefile):
KdecoreModuleMakefile.finalise(self)
class KdeuiModuleMakefile(KdefxModuleMakefile):
- """The Makefile class for modules that %Import kdeui.
+ """The Makefile class for modules that %Import tdeui.
"""
def finalise(self):
@@ -211,7 +211,7 @@ class KjsModuleMakefile(KhtmlModuleMakefile):
KjsModuleMakefile.finalise(self)
class KdeprintModuleMakefile(KdeuiModuleMakefile):
- """The Makefile class for modules that %Import kdeprint.
+ """The Makefile class for modules that %Import tdeprint.
"""
def finalise(self):